#!/bin/bash

error() {
	printf "%s\n" "$@" >&2
	exit 1
}

skip() {
	printf "%s\n" "$@"
	exit 0
}

command -v podman || skip "podman command required for this test"


cd "$(dirname "$0")" || error "cd test dir"

# prepare and clean test dir.
# we need a stable path for this as it appears in logs,
# so we can't use mktemp
TESTDIR=$(mktemp -d /tmp/atmark-x2-base.podman_rw.XXXXXX) \
	|| error "Could not create temp dir"
trap 'rm -rf "$TESTDIR"' EXIT

echo "FROM scratch" \
	| ../tools/abos-ctrl podman-rw --root "$TESTDIR" \
		build \
		-t testimage:latest \
		-f - \
	|| error "build failed"
LIST="$(../tools/abos-ctrl podman-rw --root "$TESTDIR" \
		image list --format "{{.Names}}")" \
	|| error "Could not list images (testimage)"
[ "$LIST" = "[localhost/testimage:latest]" ] \
	|| error "list content was not as expected (should contain only testimage)"
../tools/abos-ctrl podman-rw --root "$TESTDIR" \
		rmi testimage \
	|| error "Could not remove image"
LIST="$(../tools/abos-ctrl podman-rw --root "$TESTDIR" \
		image list --format "{{.Names}}")" \
	|| error "Could not list images (empty)"
[ "$LIST" = "" ] \
	|| error "list content was not as expected (should be empty)"


